==> clean_framework-3.0.1.tar.gz: example/lib/routing/poke_router.dart <==
import 'package:animations/animations.dart';
import 'package:clean_framework_example/features/form/presentation/form_ui.dart';
import 'package:clean_framework_example/features/home/presentation/home_ui.dart';
import 'package:clean_framework_example/features/profile/presentation/profile_ui.dart';
import 'package:clean_framework_example/routing/routes.dart';
import 'package:clean_framework_router/clean_framework_router.dart';

class PokeRouter extends AppRouter<Routes> {
  @override
  RouterConfiguration configureRouter() {
    return RouterConfiguration(
      debugLogDiagnostics: true,
      routes: [
        AppRoute(
          route: Routes.home,
          builder: (_, __) => HomeUI(),
          routes: [
            AppRoute(
              route: Routes.form,
              builder: (_, __) => FormUI(),
            ),
            AppRoute.custom(
              route: Routes.profile,
              builder: (_, state) {
                print(state.location);
                return ProfileUI(
                  pokemonName: state.params['pokemon_name'] ?? '',
                  pokemonImageUrl: state.queryParams['image'] ?? '',
                );
              },
              transitionsBuilder: (_, animation, secondaryAnimation, child) {
                return SharedAxisTransition(
                  animation: animation,
                  secondaryAnimation: secondaryAnimation,
                  transitionType: SharedAxisTransitionType.horizontal,
                  child: child,
                );
              },
            ),
          ],
        ),
      ],
    );
  }
}

==> clean_framework-3.2.0.tar.gz: example/lib/routing/poke_router.dart <==
import 'package:animations/animations.dart';
import 'package:clean_framework_example/features/form/presentation/form_ui.dart';
import 'package:clean_framework_example/features/home/presentation/home_ui.dart';
import 'package:clean_framework_example/features/profile/presentation/profile_ui.dart';
import 'package:clean_framework_example/routing/routes.dart';
import 'package:clean_framework_router/clean_framework_router.dart';

class PokeRouter extends AppRouter<Routes> {
  @override
  RouterConfiguration configureRouter() {
    return RouterConfiguration(
      debugLogDiagnostics: true,
      routes: [
        AppRoute(
          route: Routes.home,
          builder: (_, __) => HomeUI(),
          routes: [
            AppRoute(
              route: Routes.form,
              builder: (_, __) => FormUI(),
            ),
            AppRoute.custom(
              route: Routes.profile,
              builder: (_, state) {
                print(state.location);
                return ProfileUI(
                  pokemonName: state.params['pokemon_name'] ?? '',
                  pokemonImageUrl: state.extra as String,
                );
              },
              transitionsBuilder: (_, animation, secondaryAnimation, child) {
                return SharedAxisTransition(
                  animation: animation,
                  secondaryAnimation: secondaryAnimation,
                  transitionType: SharedAxisTransitionType.horizontal,
                  child: child,
                );
              },
            ),
          ],
        ),
      ],
    );
  }
}
